==> cbaf_1.10.1.tar.gz: cbaf/R/cbaf-constants.R <==
#####################
### RNA-Seq data ####
#####################

RNA.Seq_L1.terms <-

  c("Tumor Samples with mRNA data (RNA Seq V2)",

    "Tumors with mRNA data (RNA Seq V2)",

    "Samples with mRNA data (RNA Seq V2)",

    "Tumor Samples with mRNA data (RNA Seq)",

    "Tumors with mRNA data (RNA Seq)",

    "Samples with mRNA data (RNA Seq)")


RNA.Seq_L2.terms <-

  c("mRNA expression z-scores relative to all samples (log RNA Seq V2 RSEM)",

    "mRNA expression z-scores relative to all samples (RNA Seq RPKM)",

    "mRNA Expression z-Scores (RNA Seq V2 RSEM)",

    "mRNA expression z-Scores (RNA Seq V2 RSEM)",

    "mRNA Expression Zscores, RSEM (Batch normalized from Illumina HiSeq_RNASeqV2)",

    "mRNA Expression z-Scores (RNA Seq FPKM)",

    "mRNA Expression z-Scores (RNA Seq RPKM)",

    "mRNA expression z-scores (RNA-Seq)",

    "mRNA expression z-Scores",

    "mRNA Expression z-Scores")


#########################
### microRNA-Seq data ###
#########################

microRNA.Seq_L1.terms <-

  c("Tumor Samples with microRNA data (microRNA-Seq)",

    "Tumors with microRNA data (microRNA-Seq)",

    "Samples with microRNA data (microRNA-Seq)")

microRNA.Seq_L2.terms <-

  c("microRNA expression Z-scores",

    "mRNA Expression Z-Scores vs Normals")


#################################
### microarray with mRNA data ###
#################################

microarray.with.mRNA_L1.terms <-

  c("Tumor Samples with mRNA data (Agilent microarray)",

    "Tumors with mRNA data (Agilent microarray)",

    "Samples with mRNA data (Agilent microarray)",

    "Tumor Samples with mRNA data (U133 microarray only)",

    "Samples with mRNA data (U133 microarray)",

    "Samples with mRNA data (U133 microarray only)",

    "Tumors with mRNA data",

    "Tumors with mRNA")


microarray.with.mRNA_L2.terms <-

  c("mRNA expression z-scores relative to all samples (microarray)",

    "mRNA Expression z-Scores (microarray)",

    "mRNA expression (microarray) z-scores",

    "mRNA expression Z-scores (all genes)",

    "mRNA Expression Z-Scores vs Normals",

    "mRNA Expression z-Scores (combined microarray)",

    "mRNA Z-scores vs normal fat",

    "mRNA expression z-scores relative to all samples (U133 microarray only)",

    "mRNA Expression z-Scores (U133 microarray only)",

    "mRNA expression z-scores (Illumina)")


#####################################
### microarray with microRNA data ###
#####################################

microarray.with.microRNA_L1.terms <-

  c("Tumors with microRNA")


microarray.with.microRNA_L2.terms <-

  c("mRNA Expression Z-Scores vs Normals",

    "mRNA Expression z-Scores (combined microarray)")


########################
### methylation data ###
########################

methylation_L1.terms <-

  c("Tumor Samples with methylation data (HM450)",

    "Tumors with methylation data (HM450)",

    "Samples with methylation data (HM450)",

    "Tumor Samples with methylation data (HM27)",

    "Tumors with methylation data (HM27)",

    "Samples with methylation data (HM27)",

    "Tumors with methylation data",

    "Samples with methylation data")


methylation_L2.terms <-

  c("Methylation (HM450)",

    "Methylation (HM27)",

    "Methylation (hm27)",

    "Methylation")

==> cbaf_1.12.0.tar.gz: cbaf/R/cbaf-constants.R <==
#####################
### RNA-Seq data ####
#####################

RNA.Seq_L1.terms <-

  c("Tumor Samples with mRNA data (RNA Seq V2)",

    "Tumors with mRNA data (RNA Seq V2)",

    "Samples with mRNA data (RNA Seq V2)",

    "Tumor Samples with mRNA data (RNA Seq)",

    "Tumors with mRNA data (RNA Seq)",

    "Samples with mRNA data (RNA Seq)",

    "All samples")


RNA.Seq_L2.terms <-

  c("mRNA expression z-Scores relative to all samples (log RNA-Seq V2 RSEM)",

    "mRNA expression z-Scores relative to all samples (log RNA-Seq V2 RESM)",

    "mRNA expression z-scores relative to all samples (log RNA Seq V2 RSEM)",

    "mRNA expression z-Scores relative to all samples (log RNA Seq V2 RSEM)",

    "mRNA expression z-scores relative to all samples (log RNA Seq FPKM)",

    "mRNA expression z-Scores relative to all samples (log RNA-Seq RPKM)",

    "mRNA expression z-Scores relative to all samples (log RNA Seq RPKM)",

    "mRNA expression z-scores relative to all samples (log RNA Seq RPKM)",

    "mRNA expression z-Scores relative to all samples (log RNA Seq CPM)",

    "mRNA expression z-Scores relative to all samples (log RNA-Seq TPM)",

    "mRNA expression z-scores relative to all samples (log RNA Seq TPM)",

    "mRNA expression z-scores relative to all samples (RNA Seq RPKM)",

    "mRNA Expression z-Scores (RNA Seq V2 RSEM)",

    "mRNA expression z-Scores (RNA Seq V2 RSEM)",

    "mRNA Expression Zscores, RSEM (Batch normalized from Illumina HiSeq_RNASeqV2)",

    "mRNA Expression z-Scores (RNA Seq FPKM)",

    "mRNA Expression z-Scores (RNA Seq RPKM)",

    "mRNA expression z-scores (RNA-Seq)",

    "mRNA expression z-Scores",

    "mRNA Expression z-Scores")


#########################
### microRNA-Seq data ###
#########################

microRNA.Seq_L1.terms <-

  c("Tumor Samples with microRNA data (microRNA-Seq)",

    "Tumors with microRNA data (microRNA-Seq)",

    "Samples with microRNA data (microRNA-Seq)")

microRNA.Seq_L2.terms <-

  c("microRNA expression Z-scores",

    "mRNA Expression Z-Scores vs Normals")


#################################
### microarray with mRNA data ###
#################################

microarray.with.mRNA_L1.terms <-

  c("Tumor Samples with mRNA data (Agilent microarray)",

    "Tumors with mRNA data (Agilent microarray)",

    "Samples with mRNA data (Agilent microarray)",

    "Tumor Samples with mRNA data (U133 microarray only)",

    "Samples with mRNA data (U133 microarray)",

    "Samples with mRNA data (U133 microarray only)",

    "Tumors with mRNA data",

    "Tumors with mRNA",

    "All samples")


microarray.with.mRNA_L2.terms <-

  c("mRNA expression z-Scores relative to all samples (log microarray)",

    "mRNA expression z-scores relative to all samples (log microarray)",

    "mRNA expression z-scores relative to all samples (log U133 microarray)",

    "mRNA expression z-scores relative to all samples (microarray)",

    "mRNA Expression z-Scores (microarray)",

    "mRNA expression (microarray) z-scores",

    "mRNA expression Z-scores (all genes)",

    "mRNA Expression Z-Scores vs Normals",

    "mRNA Expression z-Scores (combined microarray)",

    "mRNA Z-scores vs normal fat",

    "mRNA expression z-scores relative to all samples (U133 microarray only)",

    "mRNA Expression z-Scores (U133 microarray only)",

    "mRNA expression z-scores (Illumina)")


#####################################
### microarray with microRNA data ###
#####################################

microarray.with.microRNA_L1.terms <-

  c("Tumors with microRNA")


microarray.with.microRNA_L2.terms <-

  c("mRNA Expression Z-Scores vs Normals",

    "mRNA Expression z-Scores (combined microarray)")


########################
### methylation data ###
########################

methylation_L1.terms <-

  c("Tumor Samples with methylation data (HM450)",

    "Tumors with methylation data (HM450)",

    "Samples with methylation data (HM450)",

    "Tumor Samples with methylation data (HM27)",

    "Tumors with methylation data (HM27)",

    "Samples with methylation data (HM27)",

    "Tumors with methylation data",

    "Samples with methylation data")


methylation_L2.terms <-

  c("Methylation (HM450)",

    "Methylation (HM27)",

    "Methylation (hm27)",

    "Methylation")
